Description Usage Arguments Value
View source: R/parallel_cluster.R
Creates edge List in Parallel
1 | parallel_cluster(nbatches, batch_len, Ngenes, mat, prob = 0.65)
|
nbatches |
Number of batches to consider. |
batch_len |
size of each batches |
Ngenes |
Number of genes to consider for each batch |
mat |
The preprocessed matrix with geans in each column and samples in every row. |
prob |
The quantile below which edges are not formed |
Returns the edgelist
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.